# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGoogleDriveFolders(BaseModel):
    google_drive_folders: Optional["QueryGoogleDriveFoldersGoogleDriveFolders"] = Field(
        alias="googleDriveFolders"
    )


class QueryGoogleDriveFoldersGoogleDriveFolders(BaseModel):
    results: Optional[
        List[Optional["QueryGoogleDriveFoldersGoogleDriveFoldersResults"]]
    ]


class QueryGoogleDriveFoldersGoogleDriveFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QueryGoogleDriveFolders.model_rebuild()
QueryGoogleDriveFoldersGoogleDriveFolders.model_rebuild()
