# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGoogleCalendars(BaseModel):
    google_calendars: Optional["QueryGoogleCalendarsGoogleCalendars"] = Field(
        alias="googleCalendars"
    )


class QueryGoogleCalendarsGoogleCalendars(BaseModel):
    results: Optional[List[Optional["QueryGoogleCalendarsGoogleCalendarsResults"]]]


class QueryGoogleCalendarsGoogleCalendarsResults(BaseModel):
    calendar_name: Optional[str] = Field(alias="calendarName")
    calendar_id: Optional[str] = Field(alias="calendarId")


QueryGoogleCalendars.model_rebuild()
QueryGoogleCalendarsGoogleCalendars.model_rebuild()
