# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalTest(BaseModel):
    create_medical_test: Optional["CreateMedicalTestCreateMedicalTest"] = Field(
        alias="createMedicalTest"
    )


class CreateMedicalTestCreateMedicalTest(BaseModel):
    id: str
    name: str


CreateMedicalTest.model_rebuild()
