# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalStudies(BaseModel):
    count_medical_studies: Optional["CountMedicalStudiesCountMedicalStudies"] = Field(
        alias="countMedicalStudies"
    )


class CountMedicalStudiesCountMedicalStudies(BaseModel):
    count: Optional[Any]


CountMedicalStudies.model_rebuild()
