# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalDrug(BaseModel):
    delete_medical_drug: Optional["DeleteMedicalDrugDeleteMedicalDrug"] = Field(
        alias="deleteMedicalDrug"
    )


class DeleteMedicalDrugDeleteMedicalDrug(BaseModel):
    id: str
    state: EntityState


DeleteMedicalDrug.model_rebuild()
