# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalContraindications(BaseModel):
    delete_all_medical_contraindications: Optional[
        List[
            Optional[
                "DeleteAllMedicalContraindicationsDeleteAllMedicalContraindications"
            ]
        ]
    ] = Field(alias="deleteAllMedicalContraindications")


class DeleteAllMedicalContraindicationsDeleteAllMedicalContraindications(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalContraindications.model_rebuild()
