# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalDrug(BaseModel):
    update_medical_drug: Optional["UpdateMedicalDrugUpdateMedicalDrug"] = Field(
        alias="updateMedicalDrug"
    )


class UpdateMedicalDrugUpdateMedicalDrug(BaseModel):
    id: str
    name: str


UpdateMedicalDrug.model_rebuild()
