# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountCategories(BaseModel):
    count_categories: Optional["CountCategoriesCountCategories"] = Field(
        alias="countCategories"
    )


class CountCategoriesCountCategories(BaseModel):
    count: Optional[Any]


CountCategories.model_rebuild()
