# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalConditions(BaseModel):
    count_medical_conditions: Optional[
        "CountMedicalConditionsCountMedicalConditions"
    ] = Field(alias="countMedicalConditions")


class CountMedicalConditionsCountMedicalConditions(BaseModel):
    count: Optional[Any]


CountMedicalConditions.model_rebuild()
