# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpsertCategory(BaseModel):
    upsert_category: Optional["UpsertCategoryUpsertCategory"] = Field(
        alias="upsertCategory"
    )


class UpsertCategoryUpsertCategory(BaseModel):
    id: str
    name: str


UpsertCategory.model_rebuild()
