# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SpecificationExists(BaseModel):
    specification_exists: Optional["SpecificationExistsSpecificationExists"] = Field(
        alias="specificationExists"
    )


class SpecificationExistsSpecificationExists(BaseModel):
    result: Optional[bool]


SpecificationExists.model_rebuild()
