# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryDropboxFolders(BaseModel):
    dropbox_folders: Optional["QueryDropboxFoldersDropboxFolders"] = Field(
        alias="dropboxFolders"
    )


class QueryDropboxFoldersDropboxFolders(BaseModel):
    results: Optional[List[Optional["QueryDropboxFoldersDropboxFoldersResults"]]]


class QueryDropboxFoldersDropboxFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QueryDropboxFolders.model_rebuild()
QueryDropboxFoldersDropboxFolders.model_rebuild()
